@@ -10,8 +10,8 @@ use std::ops::Add;
 
 /// used in feeder oracle
 pub struct MsgAggregateExchangeRatePreVote {
-    pub hash: String,
     pub feeder: String,
+    pub hash: String,
     pub validator: String,
 }
 
@@ -20,8 +20,8 @@ impl MsgAggregateExchangeRatePreVote {
     /// Create a pre vote message
     pub fn create(hash: String, feeder: String, validator: String) -> Message {
         let internal = MsgAggregateExchangeRatePreVote {
-            hash,
             feeder,
+            hash,
             validator,
         };
         Message {
@@ -35,10 +35,10 @@ impl MsgAggregateExchangeRatePreVote {
 
 /// used in feeder oracle to submit exchange rates
 pub struct MsgAggregateExchangeRateVote {
-    /// The salt is used in the next round's 'PreVote'
-    pub salt: String,
     pub exchange_rates: String,
     pub feeder: String,
+    /// The salt is used in the next round's 'PreVote'
+    pub salt: String,
     pub validator: String,
 }
 
@@ -98,6 +98,15 @@ impl MsgAggregateExchangeRateVote {
             value: Box::new(internal),
         }
     }
+    /// Create a vote message from internal message
+    pub fn create_from_internal(internal: MsgAggregateExchangeRateVote) -> Message {
+        //  let internal =
+        //      MsgAggregateExchangeRateVote::create_internal(salt, exchange_rates, feeder, validator);
+        Message {
+            s_type: "oracle/MsgAggregateExchangeRateVote".into(),
+            value: Box::new(internal),
+        }
+    }
 
     /// Pre-Vote messages are like a 'linked list'.
     /// they use the salt of the previous 'RateVote' to hash the current prices, to ensure continuity
@@ -114,14 +123,14 @@ impl MsgAggregateExchangeRateVote {
 /// used in feeder oracle
 
 pub struct MsgDelegateFeedConsent {
-    pub operator: String,
     pub delegate: String,
+    pub operator: String,
 }
 impl MsgInternal for MsgDelegateFeedConsent {}
 impl MsgDelegateFeedConsent {
     /// Create a pre vote message
     pub fn create(operator: String, delegate: String) -> Message {
-        let internal = MsgDelegateFeedConsent { operator, delegate };
+        let internal = MsgDelegateFeedConsent { delegate, operator };
         Message {
             s_type: "oracle/MsgDelegateFeedConsent".into(),
             value: Box::new(internal),
